@@ -13,7 +13,7 @@ pots = [ Brenner, BrennerScr, Tersoff, TersoffScr, Rebo2, Rebo2Scr, Rebo2SiCH, R
 
 for pot in pots:
     a = ase.io.read('rho_2.9.traj')
-    a.set_calculator(pot())
+    a.calc = pot()
     t = timeit.timeit('a.get_potential_energy()',
     	              setup='from __main__ import a',
     			      number=100)
